@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2016-06-09'; # DATE
-our $VERSION = '0.43'; # VERSION
+our $DATE = '2016-08-03'; # DATE
+our $VERSION = '0.44'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,6 +66,7 @@ sub _scan_prereqs {
             "lib", "bin", "script", "scripts",
             #"sample", "samples", "example", "examples" # decidedly not included
             #"share", # decidedly not included
+            @{ $args{extra_runtime_dirs} // [] },
         ));
         last unless @dirs;
         find(
@@ -79,7 +80,10 @@ sub _scan_prereqs {
     }
 
     {
-        my @dirs = (grep {-d} ("t", "xt"));
+        my @dirs = (grep {-d} (
+            "t", "xt",
+            @{ $args{extra_test_dirs} // [] },
+        ));
         last unless @dirs;
         find(
             sub {
@@ -176,6 +180,16 @@ _
             schema => ['str*'],
             summary => 'Perl version to use (overrides scan_prereqs/dist.ini)',
         },
+        extra_runtime_dirs => {
+            'x.name.is_plural' => 1,
+            schema => ['array*', of=>'str*'],
+            summary => 'Add extra directories to scan for runtime requirements',
+        },
+        extra_test_dirs => {
+            'x.name.is_plural' => 1,
+            schema => ['array*', of=>'str*'],
+            summary => 'Add extra directories to scan for test requirements',
+        },
         lite => {
             schema => ['bool*'],
             default => 0,
@@ -314,7 +328,11 @@ sub lint_prereqs {
     }, "t/lib") if -d "t/lib";
     $log->tracef("Dist packages (in tests): %s", \%test_dist_pkgs);
 
-    my %mods_from_scanned = _scan_prereqs(lite=>$args{lite});
+    my %mods_from_scanned = _scan_prereqs(
+        lite => $args{lite},
+        extra_runtime_dirs => $args{extra_runtime_dirs},
+        extra_test_dirs    => $args{extra_test_dirs},
+    );
     $log->tracef("mods_from_scanned: %s", \%mods_from_scanned);
 
     if ($mods_from_ini{Any}{perl} && $mods_from_scanned{Any}{perl}) {
@@ -596,7 +614,7 @@ App::LintPrereqs - Check extraneous/missing/incorrect prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.43 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-06-09.
+This document describes version 0.44 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-08-03.
 
 =head1 SYNOPSIS
 
@@ -668,6 +686,14 @@ If set to 0 (the default), will complain if there are prerequisites to core
 modules. If set to 1, prerequisites to core modules are required just like other
 modules.
 
+=item * B<extra_runtime_dirs> => I<array[str]>
+
+Add extra directories to scan for runtime requirements.
+
+=item * B<extra_test_dirs> => I<array[str]>
+
+Add extra directories to scan for test requirements.
+
 =item * B<fix> => I<bool>
 
 Attempt to automatically fix the errors.
